################################################################################
# read in QuaMeter1.csv data
# where the time span and the sample type has been figured out
# using the file name and the timestamp information
################################################################################

library(lattice)


set.seed(124)
metrics<-read.csv(file="C:\\Study1codes\\Study1codes\\QuaMeter1.csv", header=T) # save QuaMeter1.csv in your local drive and read in the data
str(metrics)

# remove the 2009  for QTOF A65089 files 
metrics<-metrics[metrics$days<900,]
#'data.frame':   244 obs. of  53 variables:

# look at the distribution of site and instrument
table(metrics$sitenumber, metrics$instrument)

# order the data in sample type, site number, and run order.
colnames(metrics)
#####################################################################
#
# [1] "X"                      "Filename"               "Digestion"              "StartTimeStamp"
# [5] "date"                   "days"                   "XIC.WideFrac"           "XIC.FWHM.Q1"
# [9] "XIC.FWHM.Q2"            "XIC.FWHM.Q3"            "XIC.Height.Q2"          "XIC.Height.Q3"
#[13] "XIC.Height.Q4"          "RT.Duration"            "RT.TIC.Q1"              "RT.TIC.Q2"
#[17] "RT.TIC.Q3"              "RT.TIC.Q4"              "RT.MS.Q1"               "RT.MS.Q2"
#[21] "RT.MS.Q3"               "RT.MS.Q4"               "RT.MSMS.Q1"             "RT.MSMS.Q2"
#[25] "RT.MSMS.Q3"             "RT.MSMS.Q4"             "MS1.TIC.Change.Q2"      "MS1.TIC.Change.Q3"
#[29] "MS1.TIC.Change.Q4"      "MS1.TIC.Q2"             "MS1.TIC.Q3"             "MS1.TIC.Q4"
#[33] "MS1.Count"              "MS1.Freq.Max"           "MS1.Density.Q1"         "MS1.Density.Q2"
#[37] "MS1.Density.Q3"         "MS2.Count"              "MS2.Freq.Max"           "MS2.Density.Q1"
#[41] "MS2.Density.Q2"         "MS2.Density.Q3"         "MS2.PrecZ.1"            "MS2.PrecZ.2"
#[45] "MS2.PrecZ.3"            "MS2.PrecZ.4"            "MS2.PrecZ.5"            "MS2.PrecZ.more"
#[49] "MS2.PrecZ.likely.1"     "MS2.PrecZ.likely.multi" "instrument"             "site"
#[53] "sitenumber"
##############################################################################
metrics$StartTimeStamp<-as.character(metrics$StartTimeStamp)

metrics$date<-NULL
for ( i in 1:nrow(metrics)){
metrics$date[i]<-ifelse(nchar(metrics$StartTimeStamp[i])<10, paste(substr(metrics$StartTimeStamp[i],1,4),"-",
                          substr(metrics$StartTimeStamp[i],5,6),"-01 00:00:00", sep=""),
                          paste(substr(metrics$StartTimeStamp[i],1,10)," ",
                          substr(metrics$StartTimeStamp[i],12,19), sep="")) }
                          
metrics.ord<-metrics[order(metrics$Digestion, metrics$site, as.numeric(strptime(metrics$date,"%Y-%m-%d %H:%M:%S"))),]
metrics<-metrics.ord
site.color<-c("#FF69B4","#8B3A62","#EE6363","#8B8B83","#ADD8E6",
             "#20B2AA","#8470FF","#6E7B8B","#32CD32","#FF00FF",
             "#AB82FF","#191970","#20B2AA","#C0FF3E","#EE4000",
             "#A020F0")
site.pch<-c(seq(1,16))

metrics$site<-as.character(metrics$site)
metrics$Digestion<-as.character(metrics$Digestion)
id<-unique(metrics$site)

# now
# 1. remove RT duration
# 2. remove all
#MS2-PrecZ-1
#MS2-PrecZ-2
#MS2-PrecZ-3
#MS2-PrecZ-4
#MS2-PrecZ-5
#MS2-PrecZ-more
# 3. remove all
#MS2.PrecZ.likely.1
#MS2.PrecZ.likely.multi
# 4. remove
#XIC.FWHM.Q1
#XIC.FWHM.Q3


myvars <- colnames(metrics) %in% c("XIC.FWHM.Q1",
"XIC.FWHM.Q3","RT.Duration",
"MS2.PrecZ.1","MS2.PrecZ.2","MS2.PrecZ.3",
"MS2.PrecZ.4" ,"MS2.PrecZ.5","MS2.PrecZ.more" ,"MS2.PrecZ.likely.1","MS2.PrecZ.likely.multi" )

metrics.1<-metrics[!myvars]

#  PCA analysis
# robust PCA analysis
library(MASS)
library(psych)

metrics.pca<-metrics.1[,6:38]
robust.cov<-cov.rob(metrics.pca)      # robust covariance
robust.cor<-cov2cor(robust.cov$cov)   # correlation matrix
robust.cor.1<-robust.cov
robust.cor.1$cov<-robust.cor
metrics.pca.1<-metrics.pca
for ( i in 1:ncol(metrics.pca)){
robust.cor.1$center[i]<-robust.cov$center[i]/sqrt(robust.cov$cov[i,i])
metrics.pca.1[,i]<-metrics.pca[,i]/sqrt(robust.cov$cov[i,i])
}

summary(pc.cr <- princomp(metrics.pca.1, covmat = robust.cor.1, scores=T))

###############################PCA for STUDY 1 WITH ALL DATA#################################################################################
######                     Comp.1    Comp.2     Comp.3     Comp.4     Comp.5     Comp.6     Comp.7     Comp.8     Comp.9    Comp.10
######Standard deviation     2.6662027 2.5035278 1.79768491 1.64073583 1.57514121 1.40922196 1.22872480 1.19450543 1.10028133 0.92759021
######Proportion of Variance 0.2154132 0.1899288 0.09792942 0.08157618 0.07518393 0.06017899 0.04575044 0.04323767 0.03668542 0.02607344
######Cumulative Proportion  0.2154132 0.4053421 0.50327150 0.58484769 0.66003162 0.72021061 0.76596105 0.80919872 0.84588415 0.87195759
######                          Comp.11    Comp.12    Comp.13    Comp.14   Comp.15     Comp.16     Comp.17     Comp.18     Comp.19    Comp.20
######Standard deviation     0.86280467 0.79193276 0.71806411 0.66221406 0.5988716 0.548091054 0.515211408 0.435074591 0.425614031 0.36673760
######Proportion of Variance 0.02255854 0.01900477 0.01562473 0.01328871 0.0108681 0.009103146 0.008043721 0.005736058 0.005489312 0.00407565
######Cumulative Proportion  0.89451613 0.91352091 0.92914564 0.94243435 0.9533024 0.962405590 0.970449311 0.976185369 0.981674681 0.98575033
######                           Comp.21    Comp.22     Comp.23     Comp.24     Comp.25     Comp.26      Comp.27      Comp.28      Comp.29
######Standard deviation     0.334864037 0.30572894 0.266789802 0.265047537 0.198832786 0.189506801 0.1453678644 0.1097090152 0.0911893514
######Proportion of Variance 0.003397998 0.00283243 0.002156873 0.002128794 0.001198014 0.001088268 0.0006403581 0.0003647293 0.0002519848
######Cumulative Proportion  0.989148329 0.99198076 0.994137632 0.996266426 0.997464440 0.998552707 0.9991930655 0.9995577949 0.9998097797
######                            Comp.30      Comp.31      Comp.32      Comp.33
######Standard deviation     0.0792292324 4.722439e-06 2.872488e-06 2.583666e-06
######Proportion of Variance 0.0001902203 6.758009e-13 2.500359e-13 2.022827e-13
######Cumulative Proportion  1.0000000000 1.000000e+00 1.000000e+00 1.000000e+00
##############################################################################################################################################

loadings<-loadings(pc.cr)  ## note that blank entries are small but not zero
plot(pc.cr) # shows a screeplot.
biplot(pc.cr)
plot(pc.cr$scores[,1],pc.cr$scores[,2])  # plot of pc1 and pc2 scores

scores<-as.data.frame(pc.cr$scores)
scores$site<-NULL
scores$index<-metrics.1$X
scores$site<-metrics.1$site
scores$sitenumber<-metrics.1$sitenumber
scores$Digestion<-metrics.1$Digestion
scores$instrument<-as.character(metrics.1$instrument)
scores$days<-metrics.1$days
sites<-unique(scores$site)
library(lattice)
scores$site<-factor(scores$site, levels=as.character(sites))

site.color<-c("#FF69B4","#8B3A62","#EE6363","#8B8B83","#ADD8E6",
             "#20B2AA","#8470FF","#6E7B8B","#32CD32","#FF00FF",
             "#AB82FF","#191970","#20B2AA","#C0FF3E","#EE4000",
             "#A020F0","#FF0000","#0000CD")

pca.plot<-xyplot(Comp.2~Comp.1|Digestion,group=site, data=scores, col=site.color[1:16], pch=c(seq(1,16)),
cex=1.5,
strip = strip.custom(bg = "transparent"), par.strip.text=list(lineheight=2, lines=2,cex=2),
key = list(space = "right", adj = 0,columns=1,
 text = list(as.character(sites)),  col=site.color[1:16],
points = list(pch = c(seq(1,16)),  cex=1.5,col=site.color[1:16]))
,xlab="The First Principal Component",ylab="The Second Principal Component"
)
plot(pca.plot)

# factor analysis using the first two PC?
factor<-fa(r=robust.cor, nfactors=6, rotate="varimax",fm="ml")
print(factor$loadings, cutoff=0.5)
