set.seed(124)
route<-"route\\to\\QuaMeter1.csv"
metrics<-read.csv(file=paste(route,"\\QuaMeter1.csv",sep=""), header=T)

# remove the 2009  for QTOF A65089 files ( April 22, 2013 )
metrics<-metrics[metrics$days<900,]
#'data.frame':   244 obs. of  53 variables:

# look at the distribution of site and instrument
table(metrics$sitenumber, metrics$instrument)

metrics$StartTimeStamp<-as.character(metrics$StartTimeStamp)

metrics$date<-NULL
for ( i in 1:nrow(metrics)){
metrics$date[i]<-ifelse(nchar(metrics$StartTimeStamp[i])<10, paste(substr(metrics$StartTimeStamp[i],1,4),"-",
                          substr(metrics$StartTimeStamp[i],5,6),"-01 00:00:00", sep=""),
                          paste(substr(metrics$StartTimeStamp[i],1,10)," ",
                          substr(metrics$StartTimeStamp[i],12,19), sep="")) }
                          
metrics.ord<-metrics[order(metrics$Digestion, metrics$site, as.numeric(strptime(metrics$date,"%Y-%m-%d %H:%M:%S"))),]
metrics<-metrics.ord
site.color<-c("#FF69B4","#8B3A62","#EE6363","#8B8B83","#ADD8E6",
             "#20B2AA","#8470FF","#6E7B8B","#32CD32","#FF00FF",
             "#AB82FF","#191970","#20B2AA","#C0FF3E","#EE4000",
             "#A020F0")
site.pch<-c(seq(1,16))

metrics$site<-as.character(metrics$site)
metrics$Digestion<-as.character(metrics$Digestion)
id<-unique(metrics$site)

# now
# 1. remove RT duration
# 2. remove all
#MS2-PrecZ-1
#MS2-PrecZ-2
#MS2-PrecZ-3
#MS2-PrecZ-4
#MS2-PrecZ-5
#MS2-PrecZ-more
# 3. remove all
#MS2.PrecZ.likely.1
#MS2.PrecZ.likely.multi
# 4. remove
#XIC.FWHM.Q1
#XIC.FWHM.Q3


myvars <- colnames(metrics) %in% c("XIC.FWHM.Q1",
"XIC.FWHM.Q3","RT.Duration",
"MS2.PrecZ.1","MS2.PrecZ.2","MS2.PrecZ.3",
"MS2.PrecZ.4" ,"MS2.PrecZ.5","MS2.PrecZ.more" ,"MS2.PrecZ.likely.1","MS2.PrecZ.likely.multi" )

metrics.1<-metrics[!myvars]

#  PCA analysis
# robust PCA analysis
library(MASS)
# load the package
library(psych)

metrics.pca<-metrics.1[,6:38]
robust.cov<-cov.rob(metrics.pca)
#robust.cov<-cov.rob(metrics, method="mve")
robust.cor<-cov2cor(robust.cov$cov)
robust.cor.1<-robust.cov
robust.cor.1$cov<-robust.cor
metrics.pca.1<-metrics.pca
for ( i in 1:ncol(metrics.pca)){
robust.cor.1$center[i]<-robust.cov$center[i]/sqrt(robust.cov$cov[i,i])
metrics.pca.1[,i]<-metrics.pca[,i]/sqrt(robust.cov$cov[i,i])
}

summary(pc.cr <- princomp(metrics.pca.1, covmat = robust.cor.1, scores=T))
loadings<-loadings(pc.cr)  ## note that blank entries are small but not zero
plot(pc.cr) # shows a screeplot.
biplot(pc.cr)

scores<-as.data.frame(pc.cr$scores)
scores$site<-NULL
scores$index<-metrics.1$X
scores$site<-metrics.1$site
scores$sitenumber<-metrics.1$sitenumber
scores$Digestion<-metrics.1$Digestion
scores$instrument<-as.character(metrics.1$instrument)
scores$days<-metrics.1$days
sites<-unique(scores$site)

# WARNING: it takes a while to compute all the distances
distance.all<-NULL
for  ( i in 1:(nrow(scores)-1)){
 for ( j in (i+1):nrow(scores)){
#for ( i in 1:15){
#for ( j in (i+1):16){
 run1<-scores[i,1:33]
 run2<-scores[j,1:33]
distance<-sqrt(sum((run1-run2)^2))
distance.all<-rbind(distance.all,
c(scores$index[i], scores$instrument[i],scores$site[i],scores$sitenumber[i],scores$Digestion[i],  scores$days[i],
  scores$index[j], scores$instrument[j],scores$site[j], scores$sitenumber[j],scores$Digestion[j], scores$days[j],
  distance))}
}

distance.all<-as.data.frame(distance.all)
colnames(distance.all)<-c("run1.index","run1.instrument","run1.site","run1.sitenumber","run1.digestion","run1.days",
"run2.index","run2.instrument","run2.site","run2.sitenumber","run2.digestion","run2.days","distance")
distance.all$run1.index<-as.character(distance.all$run1.index)
distance.all$run1.instrument<-as.character(distance.all$run1.instrument)
distance.all$run1.site<-as.character(distance.all$run1.site)
distance.all$run1.sitenumber<-as.numeric(as.vector(distance.all$run1.sitenumber))
distance.all$run1.digestion<-as.character(distance.all$run1.digestion)
distance.all$run1.days<-as.numeric(as.vector(distance.all$run1.days))

distance.all$run2.index<-as.character(distance.all$run2.index)
distance.all$run2.instrument<-as.character(distance.all$run2.instrument)
distance.all$run2.site<-as.character(distance.all$run2.site)
distance.all$run2.sitenumber<-as.numeric(as.vector(distance.all$run2.sitenumber))
distance.all$run2.digestion<-as.character(distance.all$run2.digestion)
distance.all$run2.days<-as.numeric(as.vector(distance.all$run2.days))

distance.all$distance<-as.numeric(as.vector(distance.all$distance))

# save the output to results
#write.csv(distance.all, file=paste(route, "results\\04222013\\distance.csv",sep=""),
#row.names=F)


distance.all$platform=NULL
distance.all$platform<-ifelse(distance.all$run1.instrument==distance.all$run2.instrument,"same",NA)
for ( i in 1:nrow(distance.all)){
if(is.na(distance.all$platform[i])){
if(((distance.all$run1.instrument[i]=="QIT")&(distance.all$run2.instrument[i]=="QTRAP"))|((distance.all$run2.instrument[i]=="QIT")&(distance.all$run1.instrument[i]=="QTRAP"))){distance.all$platform[i]="QIT:QTRAP"}

if(((distance.all$run1.instrument[i]=="QIT")& (distance.all$run2.instrument[i]=="Orbi"))|((distance.all$run2.instrument[i]=="QIT")&(distance.all$run1.instrument[i]=="Orbi"))){distance.all$platform[i]="QIT:Orbi"}

if(((distance.all$run1.instrument[i]=="QIT")&(distance.all$run2.instrument[i]=="QqTOF"))|((distance.all$run2.instrument[i]=="QIT")&(distance.all$run1.instrument[i]=="QqTOF"))){distance.all$platform[i]="QIT:QqTOF"}

if(((distance.all$run1.instrument[i]=="QTRAP")&(distance.all$run2.instrument[i]=="QqTOF"))|((distance.all$run2.instrument[i]=="QTRAP")&(distance.all$run1.instrument[i]=="QqTOF"))){distance.all$platform[i]="QTRAP:QqTOF"}

if(((distance.all$run1.instrument[i]=="QTRAP")&(distance.all$run2.instrument[i]=="Orbi"))|((distance.all$run2.instrument[i]=="QTRAP")&(distance.all$run1.instrument[i]=="Orbi"))){distance.all$platform[i]="QTRAP:Orbi"}

if(((distance.all$run1.instrument[i]=="QqTOF")&(distance.all$run2.instrument[i]=="Orbi"))|((distance.all$run2.instrument[i]=="QqTOF")&(distance.all$run1.instrument[i]=="Orbi"))){distance.all$platform[i]="QqTOF:Orbi"}
}
}
# save the file as it takes long time to add the platform
#write.csv(distance.all, file=paste(route, "results\\04222013\\distanceplatform.csv",sep=""),
#row.names=F)

# plot
# similarity within same lab same instruments
# sample A
distance.samelab.A<-subset(distance.all,
((run1.site==run2.site)&(run1.digestion=="1A")&(run2.digestion=="1A")))
# sample B
distance.samelab.B<-subset(distance.all,
((run1.site==run2.site)&(run1.digestion=="1B")&(run2.digestion=="1B")))
# sample A and B
distance.samelab.AB<-subset(distance.all,
((run1.site==run2.site)&(run1.digestion!=run2.digestion)))

quantile(distance.samelab.A$distance, prob=c(0.25, 0.50,0.75))
#25%      50%      75% 
#1.627667 3.712444 4.825817 
IQR(distance.samelab.A$distance)
#[1] 3.198151
quantile(distance.samelab.B$distance, prob=c(0.25, 0.50,0.75))
IQR(distance.samelab.B$distance)
quantile(distance.samelab.AB$distance, prob=c(0.25, 0.50,0.75))
IQR(distance.samelab.AB$distance)

distance.samelab.A$sample<-" 1A"
distance.samelab.B$sample<-" 1B"
distance.samelab.AB$sample<-"1A:1B"

distance.samelab.1<-rbind(distance.samelab.A, distance.samelab.B,distance.samelab.AB)

library(lattice)
bwplot( run1.site~ distance|sample, horizontal=T, data=distance.samelab.1,
xlim=list(c(0,33),c(0,33),c(0,33)),
par.settings=list(box.rectangle=list(lwd=2),
         box.umbrella=list(lty=2,lwd=2),plot.symbol=list(pch=8, cex=1, col="blue")),
strip = strip.custom(bg = "transparent"), par.strip.text=list(lineheight=2, lines=2,cex=2),
scales = list(x = list(relation="free", cex=1.5), y=list(cex=1.5)),layout=c(3,1),
 xlab=list("Distance",cex=2))

# similarity across same/different labs same platforms
# sample A
distance.sameplatform.A<-subset(distance.all,
((run1.instrument==run2.instrument)&(run1.site!=run2.site)&(run1.digestion=="1A")&(run2.digestion=="1A")))
# sample B
distance.sameplatform.B<-subset(distance.all,
((run1.instrument==run2.instrument)&(run1.site!=run2.site)&(run1.digestion=="1B")&(run2.digestion=="1B")))
# sample A and B
distance.sameplatform.AB<-subset(distance.all,
((run1.instrument==run2.instrument)&(run1.site!=run2.site)&(run1.digestion!=run2.digestion)))

quantile(distance.sameplatform.A$distance, prob=c(0.25, 0.50,0.75))
IQR(distance.sameplatform.A$distance)
quantile(distance.sameplatform.B$distance, prob=c(0.25, 0.50,0.75))
IQR(distance.sameplatform.B$distance)
quantile(distance.sameplatform.AB$distance, prob=c(0.25, 0.50,0.75))
IQR(distance.sameplatform.AB$distance)

distance.sameplatform.A$sample<-" 1A"
distance.sameplatform.B$sample<-" 1B"
distance.sameplatform.AB$sample<-"1A:1B"

distance.sameplatform<-rbind(distance.sameplatform.A, distance.sameplatform.B,distance.sameplatform.AB)
max(distance.sameplatform$distance)

# compute the summary for QIT and Orbi instrument in study 1 to compare those from Study 5   (different mass spectrometer
distance.sameplatform.QITOrbi<-subset(distance.sameplatform, (run1.instrument=="QIT"|run1.instrument=="Orbi"))

quantile(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample==" 1A"], prob=c(0.25, 0.50,0.75))
IQR(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample==" 1A"])
quantile(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample==" 1B"], prob=c(0.25, 0.50,0.75))
IQR(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample==" 1B"])
quantile(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample=="1A:1B"], prob=c(0.25, 0.50,0.75))
IQR(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample=="1A:1B"])
### results######################
##########################################
#> quantile(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample==" 1A"], prob=c(0.25, 0.50,0.75))
#      25%       50%       75% 
# 6.914243  8.220742 10.371848 
#> IQR(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample==" 1A"])
#[1] 3.457605
#> quantile(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample==" 1B"], prob=c(0.25, 0.50,0.75))
#     25%      50%      75% 
#5.960770 7.745381 9.340529 
#> IQR(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample==" 1B"])
#[1] 3.379759
#> quantile(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample=="1A:1B"], prob=c(0.25, 0.50,0.75))
#      25%       50%       75% 
# 6.473220  8.351929 10.247024 
#> IQR(distance.sameplatform.QITOrbi$distance[distance.sameplatform.QITOrbi$sample=="1A:1B"])
#[1] 3.773803

bwplot(run1.instrument~ distance|sample, horizontal=T, data=distance.sameplatform,
xlim=list(c(0,33),c(0,33),c(0,33)),
 par.settings=list(box.rectangle=list(lwd=2),
         box.umbrella=list(lty=2,lwd=2),plot.symbol=list(pch=8, cex=1, col="blue")),
strip = strip.custom(bg = "transparent"), par.strip.text=list(lineheight=2, lines=2,cex=2),
scales = list(x = list(relation="free", cex=1.5), y=list(cex=1.5)),layout=c(3,1))
#dev.off()

# similarity same labs across platforms
# sample A
# across platform
distance.diffplatform1.A<-subset(distance.all,
((run1.instrument!=run2.instrument)&(run1.sitenumber==run2.sitenumber)&(run1.digestion=="1A")&(run2.digestion=="1A")))
# sample B
distance.diffplatform1.B<-subset(distance.all,
((run1.instrument!=run2.instrument)&(run1.sitenumber==run2.sitenumber)&(run1.digestion=="1B")&(run2.digestion=="1B")))
# sample A and B
distance.diffplatform1.AB<-subset(distance.all,
((run1.instrument!=run2.instrument)&(run1.sitenumber==run2.sitenumber)&(run1.digestion!=run2.digestion)))

distance.diffplatform1.A$sample<-" 1A"
distance.diffplatform1.B$sample<-" 1B"
distance.diffplatform1.AB$sample<-"1A:1B"

distance.diffplatform1<-rbind(distance.diffplatform1.A, distance.diffplatform1.B,distance.diffplatform1.AB)
max(distance.diffplatform1$distance)

bwplot( platform~distance|sample, horizontal=T, data=distance.diffplatform1,
xlim=list(c(0,33),c(0,33),c(0,33)),
scales = list(x = list(relation="free")),layout=c(3,1))

# similarity different labs across platfors
# sample A
# across platform
distance.diffplatform.A<-subset(distance.all,
((run1.instrument!=run2.instrument)&(run1.sitenumber!=run2.sitenumber)&(run1.digestion=="1A")&(run2.digestion=="1A")))
# sample B
distance.diffplatform.B<-subset(distance.all,
((run1.instrument!=run2.instrument)&(run1.sitenumber!=run2.sitenumber)&(run1.digestion=="1B")&(run2.digestion=="1B")))
# sample A and B
distance.diffplatform.AB<-subset(distance.all,
((run1.instrument!=run2.instrument)&(run1.sitenumber!=run2.sitenumber)&(run1.digestion!=run2.digestion)))

distance.diffplatform.A$sample<-" 1A"
distance.diffplatform.B$sample<-" 1B"
distance.diffplatform.AB$sample<-"1A:1B"

distance.diffplatform<-rbind(distance.diffplatform.A, distance.diffplatform.B,distance.diffplatform.AB)
max(distance.diffplatform$distance)

bwplot( platform~distance|sample, horizontal=T, data=distance.diffplatform,
xlim=list(c(0,33),c(0,33),c(0,33)),
scales = list(x = list(relation="free")),layout=c(3,1))





