route<-"path\\to\\QuaMeter1.csv"
metrics<-read.csv(file=paste(route,"\\QuaMeter1.csv",sep=""), header=T)
str(metrics)

# look at the distribution of site and instrument
table(metrics$sitenumber, metrics$instrument,metrics$Digestion )

# timeline plots
timeline<-metrics
timeline$StartTimeStamp<-as.character(timeline$StartTimeStamp)

timeline$date<-NULL
for ( i in 1:nrow(timeline)){
timeline$date[i]<-ifelse(nchar(timeline$StartTimeStamp[i])<10, paste(substr(timeline$StartTimeStamp[i],1,4),"-",
                          substr(timeline$StartTimeStamp[i],5,6),"-01 00:00:00", sep=""), paste(substr(timeline$StartTimeStamp[i],1,10)," ",
                          substr(timeline$StartTimeStamp[i],12,19), sep="")) }

timeline$date<-strptime(timeline$date,"%Y-%m-%d %H:%M:%S")
# remove the 2009  for QTOF A65089 files 
timeline<-timeline[timeline$days<900,]  

id<-unique(as.character(timeline$site))

# the above code plot the runs within 70 days from the starting date of the experiment
 par(mai=c(1,1.5,0.50,0.5))
plot(timeline$date, seq_along(timeline$date), ylim=c(0, 34),type = "n",
  yaxt = "n",   
  xaxt="n",
     xlab = "StartTimeStamp", ylab = "", 
     main="Experimental Time and Sample Types for Participants", bty = "n")
     
axis(2, seq(0,((length(id)+4)*2),  by=2), c(noquote(" "), id, noquote(" "),noquote(" "),noquote(" "),noquote(" ")), las=2)
axis(1, c(as.numeric(strptime("2006-11-06 00:00:00 EST","%Y-%m-%d %H:%M:%S")),
as.numeric(strptime("2006-12-01 00:00:00 EST","%Y-%m-%d %H:%M:%S")),
as.numeric(strptime("2007-01-01 00:58:31 EST","%Y-%m-%d %H:%M:%S")),
as.numeric(strptime("2007-01-17 00:58:31 EST","%Y-%m-%d %H:%M:%S"))),
c("Nov 6 2006","Dec 2006","Jan 2007","Jan 17 2007"), las=1)

for ( i in 1:length(id)){
temp<-subset(timeline, site==id[i])
rug(jitter(as.numeric(temp$date[temp$Digestion=="1A"]), amount=0.01),  ticksize=0.01, col="black",pos=(2*i),lwd=3)
rug(jitter(as.numeric(temp$date[temp$Digestion=="1B"]), amount=0.01),  ticksize=0.01, pch=19,col="red",pos=(2*i+0.5),lwd=3)   }
#legend(strptime("2007-01-01 00:58:31 EST","%Y-%m-%d %H:%M:%S"), 34, pch=c(19, 19), col=c("black","red"), legend=c("1A","1B"))
abline(h=12, lty=2)
abline(h=20, lty=2)
abline(h=26, lty=2)

# this selection is and should be consistent with the pca, distance and factor analysis
myvars <- colnames(timeline) %in% c("XIC.FWHM.Q1",
"XIC.FWHM.Q3","RT.Duration",
"MS2.PrecZ.1","MS2.PrecZ.2","MS2.PrecZ.3",
"MS2.PrecZ.4" ,"MS2.PrecZ.5","MS2.PrecZ.more" ,"MS2.PrecZ.likely.1","MS2.PrecZ.likely.multi" )

timeline.1<-timeline[!myvars]

# use the following codes to select 2 batches for each site
# batch 1: first three runs
# batch2: last three runs
# donot select the site for study if there do not have 6 runs or if they do ot have
# 3 runs for each batch so that we could have a balanced nested design.
batch1<-c(13, 16, 10, # LTQ73
28,29,30, #LTQ90
37, 39,40, #LTQ195
61,62,56, # LTQ295
71, 74, 77, # LTQb65
86, 85, 88, #XCTp90
108, 109, 110, # OrbiO65
128, 122, 131, #OrbiA56
135, 136, 134, #Orbi86
146, 147,148, # QSTARx54
168, 165, 167, #QSTARp90
181, 177, 179, #QSTARp52
201, 202, 203, #QSTARp95
228, 234, 231, #QTRAP73
250, 247, 249 #QTRAPp52
)

batch2<-c(12, 17, 11,#LTQ73
20, 21, 19, #LTQ90
44, 36, 35, #LTQ195
60, 54, 55, #LTQ295
66,67,68,# LTQb65
89, 84, 87, #XCTp90
103, 105, 107, # OrbiO65
123, 130, 124, #OrbiA56
140, 141, 142, #Orbi86
152, 153,154, # QSTARx54
164, 169, 166, #QSTARp90
180, 176, 178, #QSTARp52
192, 193, 194, #QSTARp95
225, 226, 227, #QTRAP73
246, 251, 248 #QTRAPp52
)

batch.effect<-timeline.1[timeline.1$X%in%c(batch1, batch2),]
batch.effect$batch<-NULL
batch.effect$batch<-ifelse(batch.effect$X%in%batch1, "Early Batch","Late Batch")
# order the file by sites and batches
batch.effect<-batch.effect[order(batch.effect$site, batch.effect$batch),]
# the L1 median for all the 90 runs
 # robust PCA analysis
library(MASS)
# load the package
set.seed(123)
library(psych)

metrics.batch<-batch.effect[,6:38]
robust.cov<-cov.rob(metrics.batch)
robust.cor<-cov2cor(robust.cov$cov)
robust.cor.1<-robust.cov
robust.cor.1$cov<-robust.cor
metrics.pca.1<-metrics.batch
for ( i in 1:ncol(metrics.pca.1)){
robust.cor.1$center[i]<-robust.cov$center[i]/sqrt(robust.cov$cov[i,i])
metrics.pca.1[,i]<-metrics.batch[,i]/sqrt(robust.cov$cov[i,i])
}

summary(pc.cr <- princomp(metrics.pca.1, covmat = robust.cor.1, scores=T))
loadings<-loadings(pc.cr)  ## note that blank entries are small but not zero
plot(pc.cr) # shows a screeplot.
biplot(pc.cr)
plot(pc.cr$scores[,1],pc.cr$scores[,2])

scores<-as.data.frame(pc.cr$scores)
scores$site<-NULL
scores$index<-batch.effect$X
scores$site<-as.character(batch.effect$site)
scores$sitenumber<-batch.effect$sitenumber
scores$Digestion<-batch.effect$Digestion
scores$instrument<-NULL
scores$instrument<-as.character(batch.effect$instrument)
scores$days<-batch.effect$days
sites<-unique(scores$site)
scores$site<-factor(scores$site, levels=as.character(sites))

library(lattice)

site.color<-c("#FF69B4","#8B3A62","#EE6363",
             "#20B2AA","#8470FF","#6E7B8B","#32CD32","#FF00FF",
             "#AB82FF","#191970","#20B2AA","#C0FF3E","#EE4000",
             "#A020F0","#FF0000","#0000CD")

pca.plot<-xyplot(Comp.2~Comp.1,group=site, data=scores, col=site.color[1:15], pch=c(seq(1,15)),cex=1,
key = list(space = "right", adj = 0,columns=1,
 text = list(as.character(sites)),  col=site.color[1:15],
points = list(pch = c(seq(1,15)),  cex=1,col=site.color[1:15]))
, xlab="The First Principal Component",ylab="The Second Principal Component"
)
plot(pca.plot)
# calculate the L1-distance from L1 median for each run
library(pcaPP)

# L1 multivariate median
metrics.batch.std<-scores[,1:33]  
 L1median<- l1median(metrics.batch.std)
 print(L1median)
  # compare with coordinate-wise median:
 coordmedian<- apply(metrics.batch.std,2,median)
sum(abs( L1median-coordmedian))

# calculate L1 distance for each run
metrics.batch.std$L1.distance<-NULL
for ( i in 1:nrow(metrics.batch.std)){
metrics.batch.std$L1.distance[i]<-sum(abs(metrics.batch.std[i,1:33]-L1median))
}

# anova analysis
# ANOVA on the distance with site and site(batch) as factor
batch.std<-subset(metrics.batch.std, select="L1.distance")
batch.std$site<-as.character(batch.effect$site)
batch.std$batch<-as.character(batch.effect$batch)

# then 33 on each of the original metrics and combine the results together

batch.std$site<-factor(batch.std$site)
batch.std$batch<-factor(batch.std$batch)

batch.test<-aov(log(L1.distance)~ site/batch,data=batch.std)
batch.anova<-c("L1.distance",as.numeric(as.vector(anova(batch.test)[[3]])))
#           Df Sum Sq Mean Sq F value   Pr(>F)    
#site        14  6.021  0.4301  24.243  < 2e-16 ***
#site:batch  15  1.654  0.1103   6.216 1.26e-07 ***
#Residuals   60  1.064  0.0177                     
#---
#Signif. codes:  0 *** 0.001 ** 0.01 * 0.05 . 0.1   1

batch.effect$site<-factor(batch.effect$site)
batch.effect$batch<-factor(batch.effect$batch)

for ( i in 1:33){
batch.effect$var<-NULL
batch.effect$var<-batch.effect[,(5+i)]
batch.temp<-aov(log(var)~ site/batch, data=batch.effect)
batch.anova<-rbind(batch.anova, c(colnames(batch.effect)[5+i],as.numeric(as.vector(anova(batch.temp)[[3]]))))}
colnames(batch.anova)<-c("var","site","batch_site","mse")

rownames(batch.anova)<-NULL
batch.anova<-as.data.frame(batch.anova)
batch.anova$site<-as.numeric(as.vector(batch.anova$site))
batch.anova$batch_site<-as.numeric(as.vector(batch.anova$batch_site))
batch.anova$mse<-as.numeric(as.vector(batch.anova$mse))


batch.anova$F_site=batch.anova$site/batch.anova$batch_site
batch.anova$p_site=1-pf(batch.anova$F_site,9,10)
batch.anova$F_batch=batch.anova$batch_site/batch.anova$mse
batch.anova$p_batch=1-pf(batch.anova$F_batch,10,40)
batch.anova$sigma=batch.anova$mse
batch.anova$sigmaalpha=ifelse(((batch.anova$site-batch.anova$batch_site)/6)>0,
((batch.anova$site-batch.anova$batch_site)/6),0)
batch.anova$sigmabeta=ifelse(((batch.anova$batch_site-batch.anova$mse)/3)>0,
((batch.anova$batch_site-batch.anova$mse)/3),0)
batch.anova$total.var= batch.anova$sigmaalpha+batch.anova$sigmabeta+ batch.anova$sigma
batch.anova$alpha.prop<-batch.anova$sigmaalpha/ batch.anova$total.var
batch.anova$beta.prop<-batch.anova$sigmabeta/ batch.anova$total.var
batch.anova$sigma.prop<-batch.anova$sigma/ batch.anova$total.var


sum(batch.anova$p_site<0.05)
sum(batch.anova$p_batch<0.05)
p.cutoff<-0.05/66

batch.anova$site.sig<-ifelse(batch.anova$p_site<p.cutoff, 1,0)
batch.anova$batch.sig<-ifelse(batch.anova$p_batch<p.cutoff, 1,0)

sum(batch.anova$site.sig)
sum(batch.anova$batch.sig)
# different 13 metrics
batch.anova[((batch.anova$site.sig==1)|(batch.anova$batch.sig==1)),]

 batch.anova[((batch.anova$site.sig==1)),]$var
# [1] XIC.Height.Q4     RT.TIC.Q1         MS1.TIC.Change.Q2 MS1.TIC.Change.Q3 MS1.TIC.Q4        MS1.Count
# [7] MS1.Freq.Max      MS1.Density.Q1    MS2.Count         MS2.Freq.Max      MS2.Density.Q1    MS2.Density.Q2
#[13] MS2.Density.Q3
#34 Levels: dist MS1.Count MS1.Density.Q1 MS1.Density.Q2 MS1.Density.Q3 MS1.Freq.Max MS1.TIC.Change.Q2 ... XIC.WideFrac
batch.anova[((batch.anova$batch.sig==1)),]$var

# plot of the total variability
##################################
 library(lattice)
lattice.anova<-as.table(as.matrix(subset(batch.anova,select=c("alpha.prop","beta.prop","sigma.prop") ) ))
rownames(lattice.anova)<-batch.anova$var
barchart.plot<-barchart(prop.table(lattice.anova, margin=1),col=c("cyan","purple","green"), stack=TRUE,
strip = strip.custom(bg = "transparent"), par.strip.text=list(lineheight=2,cex=2),
scales = list(x = list(relation="same", cex=1.5), y=list(relation="same", cex=1)),
key = list(space="top",columns=3,points=list(pch=c(22,22,22),fill=c("cyan","purple","green"),cex=2), 
text = list(as.character(c("mass spectrometer ","nested batch","residuals")),cex=2)),
xlab=list("Proportions",cex=2))
plot(barchart.plot)

############################
